@@ -148,6 +148,10 @@ class CORSTestFilterFactory(test_base.BaseTestCase):
                           allow_methods='GET',
                           allow_headers='')
 
+    def test_no_origin_but_oslo_config_project(self):
+        '''Assert that a filter factory with oslo_config_project succeed.'''
+        cors.filter_factory(global_conf=None, oslo_config_project='foobar')
+
 
 class CORSRegularRequestTest(CORSTestBase):
     """CORS Specification Section 6.1
@@ -1019,6 +1023,19 @@ class CORSTestWildcard(CORSTestBase):
                                 allow_credentials='true',
                                 expose_headers=None)
 
+        # Test valid domain
+        request = webob.Request.blank('/')
+        request.method = "GET"
+        request.headers['Origin'] = 'http://default.example.com'
+        response = request.get_response(self.application)
+        self.assertCORSResponse(response,
+                                status='200 OK',
+                                allow_origin='http://default.example.com',
+                                max_age=None,
+                                allow_headers='',
+                                allow_credentials='true',
+                                expose_headers=None)
+
         # Test invalid domain
         request = webob.Request.blank('/')
         request.method = "OPTIONS"
